@@ -27,6 +27,7 @@
 #ifndef KCMAUDIOCD_H
 #define KCMAUDIOCD_H
 
+#include "kcoreaddons_version.h"
 #include <KCModule>
 #include <KConfig>
 #include <QList>
@@ -50,10 +51,15 @@ class KAudiocdModule : public KCModule
     Q_OBJECT
 
 public:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     explicit KAudiocdModule(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#else
+    explicit KAudiocdModule(QObject *parent, const KPluginMetaData &md);
+#endif
     ~KAudiocdModule() override;
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QString quickHelp() const override;
+#endif
 
 public Q_SLOTS:
   void defaults() override;
@@ -67,13 +73,16 @@ private Q_SLOTS:
   void slotModuleChanged();
 
 private:
-  KConfig *config;
-  bool configChanged = false;
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 105, 0)
+    QWidget *widget();
+#endif
+    KConfig *config = nullptr;
+    bool configChanged = false;
 
-  int getBitrateIndex(int value);
+    int getBitrateIndex(int value);
 
-  QList<KConfigDialogManager *> encoderSettings;
-  AudiocdConfig *audioConfig;
+    QList<KConfigDialogManager *> encoderSettings;
+    AudiocdConfig *audioConfig = nullptr;
 };
 
 #endif // KCMAUDIOCD_H
